@@ -31,7 +31,8 @@ class UDFMaster(object):
         if "num_cpus" in conf:
             udf_worker_conf["num_cpus"] = float(conf["num_cpus"])
 
-        if "num_gpus" in conf:
+        infer_backend =  conf.get("infer_backend", "transformers")
+        if "num_gpus" in conf and not infer_backend.startswith("ray/"):
             udf_worker_conf["num_gpus"] = float(conf["num_gpus"])
 
         custom_resources = [(key.split("resource.")[1], float(conf[key])) for key in
